@@ -20,15 +20,14 @@ public:
   NS_DECL_ISUPPORTS
   NS_DECL_MOZIVISITINFO
 
-  VisitInfo(PRInt64 aVisitId, PRTime aVisitDate, PRUint32 aTransitionType,
-            already_AddRefed<nsIURI> aReferrer, PRInt64 aSessionId);
+  VisitInfo(int64_t aVisitId, PRTime aVisitDate, uint32_t aTransitionType,
+            already_AddRefed<nsIURI> aReferrer);
 
 private:
-  const PRInt64 mVisitId;
+  const int64_t mVisitId;
   const PRTime mVisitDate;
-  const PRUint32 mTransitionType;
+  const uint32_t mTransitionType;
   nsCOMPtr<nsIURI> mReferrer;
-  const PRInt64 mSessionId;
 };
 
 } // namespace places
